@@ -61,38 +61,9 @@ int wanpipe_hdlc_decode (wanpipe_hdlc_engine_t *hdlc_eng,
 			 unsigned char *buf, int len)
 {
 	int i;
-	int word_len;
-	int found=1;
 	int gotdata=0;
 
 	
-	word_len=len-(len%4);
-	/* Before decoding the packet, make sure that the current
-	 * bit stream contains data. Decoding is very expensive,
-	 * thus perform word (32bit) comparision test */
-	
-
-#if 0
-	for (i=0;i<word_len;i+=4){
-		if ((*(unsigned int*)&buf[i]) != *(unsigned int*)buf){
-			found=1;
-			break;
-		}
-	}
-
-	if ((len%4) && !found){
-		for (i=word_len;i<len;i++){
-			if (buf[i]!=buf[0]){
-				found=1;
-				break;
-			}
-		}
-	}
-#endif
-	
-	/* Data found proceed to decode
-	 * the bitstream and pull out data packets */
-	if (found){
 		wanpipe_hdlc_decoder_t *hdlc_decoder = &hdlc_eng->decoder;
 
 		for (i=0; i<len; i++){
@@ -107,7 +78,6 @@ int wanpipe_hdlc_decode (wanpipe_hdlc_engine_t *hdlc_eng,
 			hdlc_decoder->stats.frame_overflow++;	
 			init_hdlc_decoder(hdlc_decoder);
 		}
-	}
 	
 	return gotdata;
 }
