@@ -1494,7 +1494,7 @@ int wanpipe_tdm_api_ioctl(wanpipe_tdm_api_dev_t *tdm_api, struct ifreq *ifr)
 		if (card && card->wandev.ec_enable && card->wandev.ec_dev) {
 			wan_smp_flag_t smp_flags1;
 			card->hw_iface.hw_lock(card->hw,&smp_flags1);   
-                	card->wandev.ec_enable(card, 1, tdm_api->tdm_chan);
+            err=card->wandev.ec_enable(card, 1, tdm_api->tdm_chan);
 			card->hw_iface.hw_unlock(card->hw,&smp_flags1);   
 		}
 		break;
@@ -1503,7 +1503,7 @@ int wanpipe_tdm_api_ioctl(wanpipe_tdm_api_dev_t *tdm_api, struct ifreq *ifr)
 		if (card && card->wandev.ec_enable && card->wandev.ec_dev) {
 			wan_smp_flag_t smp_flags1;
 			card->hw_iface.hw_lock(card->hw,&smp_flags1);   
-                	card->wandev.ec_enable(card, 0, tdm_api->tdm_chan);
+            err=card->wandev.ec_enable(card, 0, tdm_api->tdm_chan);
 			card->hw_iface.hw_unlock(card->hw,&smp_flags1);   
 		}
 		break;	
