@@ -205,6 +205,7 @@ struct media_session {
     int sangoma_sock;
     char *ip;
     int port;
+	char *raw;
     time_t started;
     time_t answered;
     pthread_t thread;
@@ -290,6 +291,22 @@ struct woomera_interface {
 	struct woomera_interface *next;
 };
 
+#define WOOMERA_MAX_RBS_BITS 4
+
+typedef struct woomera_rbs_bits
+{
+	int init;
+	unsigned char abcd;
+}woomera_rbs_bits_t;
+
+typedef struct woomera_rbs_relay
+{
+	int init;
+	woomera_rbs_bits_t rbs_bits[WOOMERA_MAX_RBS_BITS];
+	int rx_idx;
+	int tx_idx;
+} woomera_rbs_relay_t;
+
 struct  woomera_session {
 	struct woomera_interface *dev;
 	char session[SMG_SESSION_NAME_SZ];
@@ -299,6 +316,9 @@ struct  woomera_session {
 	int clients;
 	unsigned char media_used;
 	pthread_mutex_t media_lock;
+	woomera_rbs_relay_t rbs_relay;
+	int sangoma_fd;
+	int sangoma_fd_usage;
 };
 
 struct smg_tdm_ip_bridge {
@@ -320,6 +340,9 @@ struct smg_tdm_ip_bridge {
 extern struct smg_tdm_ip_bridge g_smg_ip_bridge_idx[];
 extern pthread_mutex_t g_smg_ip_bridge_lock;
 
+
+
+
 #define MAX_SMG_RBS_RELAY 32
 #define MAX_SMG_BRIDGE 32
 #define CORE_TANK_LEN CORE_MAX_CHAN_PER_SPAN*CORE_MAX_SPANS
@@ -376,6 +399,7 @@ struct woomera_server {
 	int udp_seq; 
 	unsigned int media_rx_seq_err;
 	unsigned char rbs_relay[MAX_SMG_RBS_RELAY];
+	unsigned char media_pass_through;
 };
 
 extern struct woomera_server server;
@@ -611,6 +635,21 @@ static inline void woomera_set_raw(struct woomera_interface *woomera, char *raw)
     	}
 }
 
+static inline void media_set_raw(struct media_session *ms, char *raw)
+{
+	char *oldraw=ms->raw;
+
+	if (raw) {
+		ms->raw = smg_strdup(raw);
+	} else {
+		ms->raw = NULL;
+	}
+
+	if (oldraw) {
+		smg_free(oldraw);
+	}
+}
+
 static inline struct media_session * woomera_get_ms(struct woomera_interface *woomera)
 {
 	struct media_session *ms;
